<!-- markdownlint-disable MD041 -->
<!-- markdownlint-disable MD033 -->

% The title is set to `REANA-Client docs` instead of `REANA-Client` as this is a
% workaround to avoid having multiple HTML objects with the same id/anchor, % as
the tile clashes with the CLI API documentation generated by sphinx_click

# REANA-Client docs

```{include} ../README.md
:start-line: 1
:end-before: "## About"
```

```{include} ../README.md
:start-after: "## About"
:end-before: "## Useful links"

```

## CLI API

```{eval-rst}
.. include:: cmd_list.txt
   :literal:
```

```{eval-rst}
.. click:: reana_client.cli:cli
   :prog: reana-client
   :show-nested:
```

### Shell completion

The `reana-client` supports shell completion for Bash and Zsh. To enable the
auto-completion of commands and options, add the following to your shell
configuration file:

**Bash** (add to `~/.bashrc`):

```bash
eval "$(_REANA_CLIENT_COMPLETE=bash_source reana-client)"
```

**Zsh** (add to `~/.zshrc`):

```bash
eval "$(_REANA_CLIENT_COMPLETE=zsh_source reana-client)"
```

## API docs

```{eval-rst}
.. automodule:: reana_client.api.client
  :members:
```

```{include} ../CHANGELOG.md
:heading-offset: 1
```

```{include} ../CONTRIBUTING.md
:heading-offset: 1
```

## License

```{eval-rst}
.. include:: ../LICENSE
```

In applying this license, CERN does not waive the privileges and immunities
granted to it by virtue of its status as an Intergovernmental Organization or
submit itself to any jurisdiction.

```{include} ../AUTHORS.md
:heading-offset: 1
```
